Ocyan plugin Oscar Catalogue App Ocyan Overrides
================================================

Installation
------------
Add `ocyan.plugin.oscar_catalogue` to your projects dependencies.


Usage
-----
This plugin fixes some bugs in oscar's catalogue app, required until fixed upstream.


This app provides the following features:

1. Allows a user to set a ``min_quantity`` attribute on a product as a product
   attribute. When set, users can not order less.
2. Adds vat_rate on each product which can be zero, low or high.
3. Make option and product_type slugs editable from the django admin.
4. Sort child products (variants) by price in the dropdown so the cheapest is
   offered by default.
5. Add any media defined in views in the detail template.
6. Adds ``filter_by_attributes`` query option until merged in upstream.
7. Reduces some crazy expensive queries to calculated pagination info.
8. Test correctness of taxes very exhaustive.


Configuration
-------------

* minimum_quantity_attribute_code: Optionally a minimum order amount can be specified per product, people are not allowed to order less then specified.
* slug_id_separator: Separator between slug and id in the url.
* enforce_parent: Redirect child product detail views to the parent, defaults to false.
